@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013, 2014 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013-2015 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -78,3 +78,8 @@ void NewMailNotifierAttribute::setIgnoreNewMail(bool b)
 {
     d->ignoreNewMail = b;
 }
+
+bool NewMailNotifierAttribute::operator==(const NewMailNotifierAttribute &other) const
+{
+    return d->ignoreNewMail == other.ignoreNewMail();
+}
