@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013, 2014 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013-2015 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -17,7 +17,6 @@
 
 #include "newmailnotifiershowmessagejob.h"
 #include "specialnotifierjob.h"
-#include "util.h"
 #include "newmailnotifieragentsettings.h"
 
 #include <Akonadi/Contact/ContactSearchJob>
@@ -55,6 +54,11 @@ SpecialNotifierJob::~SpecialNotifierJob()
 
 }
 
+void SpecialNotifierJob::setDefaultPixmap(const QPixmap &pixmap)
+{
+    mDefaultPixmap = pixmap;
+}
+
 void SpecialNotifierJob::slotItemFetchJobDone(KJob *job)
 {
     if ( job->error() ) {
@@ -81,7 +85,7 @@ void SpecialNotifierJob::slotItemFetchJobDone(KJob *job)
             job->setQuery( Akonadi::ContactSearchJob::Email, KPIMUtils::firstEmailAddress(mFrom).toLower(), Akonadi::ContactSearchJob::ExactMatch );
             connect( job, SIGNAL(result(KJob*)), SLOT(slotSearchJobFinished(KJob*)) );
         } else {
-            emitNotification(Util::defaultPixmap());
+            emitNotification(mDefaultPixmap);
             deleteLater();
         }
     } else {
@@ -96,7 +100,7 @@ void SpecialNotifierJob::slotSearchJobFinished( KJob *job )
     const Akonadi::ContactSearchJob *searchJob = qobject_cast<Akonadi::ContactSearchJob*>( job );
     if ( searchJob->error() ) {
         kWarning() << "Unable to fetch contact:" << searchJob->errorText();
-        emitNotification(Util::defaultPixmap());
+        emitNotification(mDefaultPixmap);
         return;
     }
     if (!searchJob->contacts().isEmpty()) {
@@ -104,12 +108,12 @@ void SpecialNotifierJob::slotSearchJobFinished( KJob *job )
         const KABC::Picture photo = addressee.photo();
         const QImage image = photo.data();
         if (image.isNull()) {
-            emitNotification(Util::defaultPixmap());
+            emitNotification(mDefaultPixmap);
         } else {
             emitNotification(QPixmap::fromImage(image));
         }
     } else {
-        emitNotification(Util::defaultPixmap());
+        emitNotification(mDefaultPixmap);
     }
 }
 
