@@ -20,8 +20,6 @@
 
 #include "entitytreecreatejob.h"
 
-#include <QVariant>
-#include <QStringList>
 
 #include <Akonadi/CollectionCreateJob>
 #include <Akonadi/ItemCreateJob>
@@ -113,4 +111,3 @@ void EntityTreeCreateJob::collectionCreateJobDone( KJob *job )
     commit();
 }
 
-#include "entitytreecreatejob.moc"
